<?php
/*
 * Plugin Name:       Woo Minimum Purchase (EasyToolsWP)
 * Description:       Requires a minimum purchase amount before allowing checkout in WooCommerce. Manage text and amount in admin settings.
 * Version:           1.1.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Requires Plugins:  woocommerce
 */

// Check if WooCommerce is active
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

    // Add settings page as a subpage under WooCommerce
    add_action( 'admin_menu', 'woo_minimum_purchase_settings_page' );
    function woo_minimum_purchase_settings_page() {
        add_submenu_page(
            'woocommerce',
            'Minimum Purchase Settings',
            'Minimum Purchase',
            'manage_options',
            'woo-minimum-purchase',
            'woo_minimum_purchase_settings_page_html'
        );
    }

    // Register settings
    add_action( 'admin_init', 'woo_minimum_purchase_register_settings' );
    function woo_minimum_purchase_register_settings() {
        register_setting( 'woo_minimum_purchase_settings', 'woo_minimum_purchase_amount' );
        register_setting( 'woo_minimum_purchase_settings', 'woo_minimum_purchase_message' );
    }

    // Settings page HTML
    function woo_minimum_purchase_settings_page_html() {
        if ( ! current_user_can( 'manage_options' ) ) {
            return;
        }

        ?>
        <div class="wrap">
            <h1>Minimum Purchase Settings</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields( 'woo_minimum_purchase_settings' );
                do_settings_sections( 'woo_minimum_purchase_settings' );
                ?>
                <table class="form-table">
                    <tr>
                        <th scope="row"><label for="woo_minimum_purchase_amount">Minimum Purchase Amount</label></th>
                        <td>
                            <input type="number" name="woo_minimum_purchase_amount" id="woo_minimum_purchase_amount" value="<?php echo esc_attr( get_option( 'woo_minimum_purchase_amount', 99 ) ); ?>" class="small-text" />
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="woo_minimum_purchase_message">Error Message</label></th>
                        <td>
                            <textarea name="woo_minimum_purchase_message" id="woo_minimum_purchase_message" rows="5" class="large-text"><?php echo esc_textarea( get_option( 'woo_minimum_purchase_message', 'The minimum purchase amount is %s. Your current total is %s.' ) ); ?></textarea>
                            <p class="description">The minimum purchase amount is <code>%s</code>. Your current total is <code>%s</code>.</p>
                        </td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    // Add a custom error message if minimum purchase is not met in the cart or at checkout
    add_action( 'woocommerce_check_cart_items', 'minimum_purchase_amount' );
    function minimum_purchase_amount() {
        // Get settings
        $minimum_amount = get_option( 'woo_minimum_purchase_amount', 99 );
        $error_message = get_option( 'woo_minimum_purchase_message', 'The minimum purchase amount is %s. Your current total is %s.' );

        // Get cart subtotal
        $subtotal = WC()->cart->subtotal;

        // If cart subtotal is less than minimum purchase amount, display an error message
        if ( $subtotal < $minimum_amount && ! is_cart() ) {
            // Display an error message
            wc_add_notice( sprintf( 
                $error_message, 
                wc_price( $minimum_amount ), 
                wc_price( $subtotal )
            ), 'error' );
        }
    }

    // Redirect to cart if minimum purchase not met when accessing checkout page
    add_action( 'template_redirect', 'redirect_to_cart_if_minimum_purchase_not_met' );
    function redirect_to_cart_if_minimum_purchase_not_met() {
        // Get settings
        $minimum_amount = get_option( 'woo_minimum_purchase_amount', 99 );
        $error_message = get_option( 'woo_minimum_purchase_message', 'The minimum purchase amount is %s. Your current total is %s.' );

        // If user is accessing checkout page and cart subtotal is less than minimum purchase amount
        if ( is_checkout() && WC()->cart->subtotal < $minimum_amount ) {
            // Display an error message
            wc_add_notice( sprintf( 
                $error_message, 
                wc_price( $minimum_amount ),
                wc_price( WC()->cart->subtotal )
            ), 'error' );

            // Redirect to cart page
            wp_safe_redirect( wc_get_cart_url() );
            exit;
        }
    }
}
